//+------------------------------------------------------------------+
//|                                           CandleWicksDisplay.mq4 |
//|                                  Copyright  2011, Andriy Moraru |
//+------------------------------------------------------------------+
#property copyright "Copyright  2011, Andriy Moraru"
#property link      "http://www.earnforex.com"
#property strict
/*
   Alerts you when the candle's wick (shadow) reaches a certain length.
   Your e-mail settings are set in Tools -> Options -> Email.
   Also displays the candle wicks' length above and below the candles.
*/

// The indicator uses only objects for display, but the line below is required for it to work.
#property indicator_chart_window

// extern int DisplayWickLimit = 5; // In standard pips
  int UpperWickLimit = 10; // In broker pips
extern color DisplayBullColor = LimeGreen;
extern color DisplayBearColor = Red;
//extern int DisplayWickDistance = 8; // Distance from High to Pip Count
//extern int DisplayWickDistanceDaily = 100; // Distance from High to Pip Count
// extern int DisplayWickDistance = 8; // Distance from High to Pip Count
extern int Fontsize=9;
extern int TextLRShift=0;
extern string Sep="/";

extern int TextAngle=90;
extern bool WaitForClose = true; // Wait for a candle to close before checking wicks' length
extern bool EmailAlert = false;
extern bool SoundAlert = false;
extern bool VisualAlert = false;
extern int BarsToDisplay = 0;

// Time of the bar of the last alert
datetime AlertDone;

double Poin;
int TextPos;
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
	Poin = Point;
	//Checking for unconvetional Point digits number
   if ((Point == 0.00001) || (Point == 0.001)) Poin *= 10;
   
//   if(Period()==1440){
//   TextPos=DisplayWickDistanceDaily;
//   }
//   else{
//     TextPos=DisplayWickDistance;
// }
   return(0);
}

//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{
   for (int i = 0; i < Bars; i++)
   {
      ObjectDelete("Red-" + TimeToStr(Time[i], TIME_DATE|TIME_MINUTES));
      ObjectDelete("Green-" + TimeToStr(Time[i], TIME_DATE|TIME_MINUTES));
   }
   return(0);
}

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
   string name, length;
   bool DoAlert = false;
   int index = 0;
   double OpenClosePips,UpperPips,LowerPips,HighLowPips;
   
   if (WaitForClose) index = 1;
   
   int counted_bars = IndicatorCounted();
   if (counted_bars > 0) counted_bars--;
   int limit = Bars - counted_bars;
   int max = Bars; if (BarsToDisplay>0) max = MathMin(BarsToDisplay,max);
   if (limit > max) limit = max;
     
//   for (int i = 0; i <= limit; i++){
   for (int i = 0; i < limit; i++){
   
      if (Open[i] <= Close[i]){ 
         
            name = "Red-" + TimeToStr(Time[i], TIME_DATE|TIME_MINUTES);
            OpenClosePips = MathRound((Close[i] - Open[i])/Poin);
            UpperPips = MathRound((High[i] - Close[i])/Poin);
            LowerPips = MathRound((Open[i] - Low[i])/Poin);
            HighLowPips=MathRound((High[i] - Low[i])/Poin);
            length = PadNum(LowerPips)+DoubleToString(LowerPips,0)+Sep+PadNum(OpenClosePips)+DoubleToString(OpenClosePips,0)+Sep+
            PadNum(UpperPips)+DoubleToString(UpperPips,0)+Sep+PadNum(HighLowPips)+DoubleToString(HighLowPips,0);
            
            if (ObjectFind(name) != -1) ObjectDelete(name);
//            ObjectCreate(name, OBJ_TEXT, 0, Time[i+TextLRShift], High[i] + TextPos * Poin);
            ObjectCreate(name, OBJ_TEXT, 0, Time[i+TextLRShift], High[i]);
               ObjectSet(name, OBJPROP_ANGLE, TextAngle);
          ObjectSetText(name,"    "+length, Fontsize, "Verdana",DisplayBullColor);
            ObjectSetInteger(0,name,OBJPROP_ANCHOR,ANCHOR_LEFT);
      }
      
      
      else{ 
            name = "Red-" + TimeToStr(Time[i], TIME_DATE|TIME_MINUTES);
            OpenClosePips = MathRound((Open[i] - Close[i])/Poin);
            UpperPips = MathRound((High[i] - Open[i])/Poin);
            LowerPips = MathRound((Close[i] - Low[i])/Poin);
            HighLowPips=MathRound((High[i] - Low[i])/Poin);
            length = PadNum(LowerPips)+DoubleToString(LowerPips,0)+Sep+PadNum(OpenClosePips)+DoubleToString(OpenClosePips,0)+Sep+
            PadNum(UpperPips)+DoubleToString(UpperPips,0)+Sep+PadNum(HighLowPips)+DoubleToString(HighLowPips,0);
 
           if (ObjectFind(name) != -1) ObjectDelete(name);
//            ObjectCreate(name, OBJ_TEXT, 0, Time[i+TextLRShift], High[i] + TextPos * Poin);
            ObjectCreate(name, OBJ_TEXT, 0, Time[i+TextLRShift], High[i]);
            ObjectSet(name, OBJPROP_ANGLE, TextAngle);
            ObjectSetText(name,"    "+length, Fontsize, "Verdana",  DisplayBearColor);
            ObjectSetInteger(0,name,OBJPROP_ANCHOR,ANCHOR_LEFT);
      }
   }
   
   if (AlertDone == Time[index]) return(0); // Already sent an alert for this candle
   
   if (Close[index] >= Open[index]) // Bullish candle
   {
      if ((High[index] - Close[index] >= UpperWickLimit * Point)) DoAlert = true;
   }
   else // Bearish candle
   {
      if ((High[index] - Open[index] >= UpperWickLimit * Point)) DoAlert = true;
   }
   
   if (DoAlert)
   {
      datetime tc = TimeCurrent();
      string time = TimeYear(tc) + "-" + TimeMonth(tc) + "-" + TimeDay(tc) + " " + TimeHour(tc) + ":" + TimeMinute(tc);
      if (VisualAlert) Alert(time + " - wick limit reached!");
      if (SoundAlert) PlaySound("alert.wav");
      if (EmailAlert) SendMail("CandleWick Alert", time + " - wick limit reached!");
      AlertDone = Time[index];
   }
      
   return(0);
}
//+------------------------------------------------------------------+
//                                                                   +
//+------------------------------------------------------------------+
string PadNum(int s){
string pad;
if( s < 10) pad="0";

return(pad);
}
//+------------------------------------------------------------------+
